@@ -1,3 +1,25 @@
+// Copyright (C) 2004-2021 Artifex Software, Inc.
+//
+// This file is part of MuPDF.
+//
+// MuPDF is free software: you can redistribute it and/or modify it under the
+// terms of the GNU Affero General Public License as published by the Free
+// Software Foundation, either version 3 of the License, or (at your option)
+// any later version.
+//
+// MuPDF is distributed in the hope that it will be useful, but WITHOUT ANY
+// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+// FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
+// details.
+//
+// You should have received a copy of the GNU Affero General Public License
+// along with MuPDF. If not, see <https://www.gnu.org/licenses/agpl-3.0.en.html>
+//
+// Alternative licensing terms are available from the licensor.
+// For commercial licensing, see <https://www.artifex.com/> or contact
+// Artifex Software, Inc., 39 Mesa Street, Suite 108A, San Francisco,
+// CA 94129, USA, for further information.
+
 #include "mupdf/fitz.h"
 
 #include <string.h>
@@ -34,17 +56,26 @@ img_count_pages(fz_context *ctx, fz_document *doc_, int chapter)
 }
 
 static fz_rect
-img_bound_page(fz_context *ctx, fz_page *page_)
+img_bound_page(fz_context *ctx, fz_page *page_, fz_box_type box)
 {
 	img_page *page = (img_page*)page_;
 	fz_image *image = page->image;
 	int xres, yres;
 	fz_rect bbox;
+	uint8_t orientation = fz_image_orientation(ctx, page->image);
 
 	fz_image_resolution(image, &xres, &yres);
 	bbox.x0 = bbox.y0 = 0;
-	bbox.x1 = image->w * DPI / xres;
-	bbox.y1 = image->h * DPI / yres;
+	if (orientation == 0 || (orientation & 1) == 1)
+	{
+		bbox.x1 = image->w * DPI / xres;
+		bbox.y1 = image->h * DPI / yres;
+	}
+	else
+	{
+		bbox.y1 = image->w * DPI / xres;
+		bbox.x1 = image->h * DPI / yres;
+	}
 	return bbox;
 }
 
@@ -55,11 +86,22 @@ img_run_page(fz_context *ctx, fz_page *page_, fz_device *dev, fz_matrix ctm, fz_
 	fz_image *image = page->image;
 	int xres, yres;
 	float w, h;
+	uint8_t orientation = fz_image_orientation(ctx, page->image);
+	fz_matrix immat = fz_image_orientation_matrix(ctx, page->image);
 
 	fz_image_resolution(image, &xres, &yres);
-	w = image->w * DPI / xres;
-	h = image->h * DPI / yres;
-	ctm = fz_pre_scale(ctm, w, h);
+	if (orientation == 0 || (orientation & 1) == 1)
+	{
+		w = image->w * DPI / xres;
+		h = image->h * DPI / yres;
+	}
+	else
+	{
+		h = image->w * DPI / xres;
+		w = image->h * DPI / yres;
+	}
+	immat = fz_post_scale(immat, w, h);
+	ctm = fz_concat(immat, ctm);
 	fz_fill_image(ctx, dev, image, ctm, 1, fz_default_color_params);
 }
 
@@ -100,7 +142,7 @@ img_load_page(fz_context *ctx, fz_document *doc_, int chapter, int number)
 			image = fz_new_image_from_buffer(ctx, doc->buffer);
 		}
 
-		page = fz_new_derived_page(ctx, img_page);
+		page = fz_new_derived_page(ctx, img_page, doc_);
 		page->super.bound_page = img_bound_page;
 		page->super.run_page_contents = img_run_page;
 		page->super.drop_page = img_drop_page;
@@ -121,7 +163,7 @@ img_load_page(fz_context *ctx, fz_document *doc_, int chapter, int number)
 }
 
 static int
-img_lookup_metadata(fz_context *ctx, fz_document *doc_, const char *key, char *buf, int size)
+img_lookup_metadata(fz_context *ctx, fz_document *doc_, const char *key, char *buf, size_t size)
 {
 	img_document *doc = (img_document*)doc_;
 	if (!strcmp(key, FZ_META_FORMAT))
@@ -168,7 +210,8 @@ img_open_document_with_stream(fz_context *ctx, fz_stream *file)
 		else if (fmt == FZ_IMAGE_JBIG2)
 		{
 			doc->page_count = fz_load_jbig2_subimage_count(ctx, data, len);
-			doc->load_subimage = fz_load_jbig2_subimage;
+			if (doc->page_count > 1)
+				doc->load_subimage = fz_load_jbig2_subimage;
 			doc->format = "JBIG2";
 		}
 		else if (fmt == FZ_IMAGE_BMP)
@@ -192,6 +235,23 @@ img_open_document_with_stream(fz_context *ctx, fz_stream *file)
 	return (fz_document*)doc;
 }
 
+static int
+img_recognize_content(fz_context *ctx, fz_stream *stream)
+{
+	unsigned char data[8];
+	size_t n = fz_read(ctx, stream, data, 8);
+	int fmt;
+
+	if (n != 8)
+		return 0;
+
+	fmt = fz_recognize_image_format(ctx, data);
+	if (fmt != FZ_IMAGE_UNKNOWN)
+		return 100;
+
+	return 0;
+}
+
 static const char *img_extensions[] =
 {
 	"bmp",
@@ -210,11 +270,13 @@ static const char *img_extensions[] =
 	"jxr",
 	"pam",
 	"pbm",
+	"pfm",
 	"pgm",
 	"pkm",
 	"png",
 	"pnm",
 	"ppm",
+	"psd",
 	"tif",
 	"tiff",
 	"wdp",
@@ -233,6 +295,7 @@ static const char *img_mimetypes[] =
 	"image/png",
 	"image/tiff",
 	"image/vnd.ms-photo",
+	"image/vnd.adobe.photoshop",
 	"image/x-jb2",
 	"image/x-jbig2",
 	"image/x-portable-anymap",
@@ -240,6 +303,7 @@ static const char *img_mimetypes[] =
 	"image/x-portable-bitmap",
 	"image/x-portable-greymap",
 	"image/x-portable-pixmap",
+	"image/x-portable-floatmap",
 	"image/x-tiff",
 	NULL
 };
@@ -252,5 +316,6 @@ fz_document_handler img_document_handler =
 	img_extensions,
 	img_mimetypes,
 	NULL,
-	NULL
+	NULL,
+	img_recognize_content
 };
